@@ -20,26 +20,29 @@ class ParentChildCounter(object):
 
     def get_count_for(
         self,
-        parent_image_name: str,
-        child_image_name: Optional[str] = None,
+        parent_process_name: str,
+        child_process_name: Optional[str] = None,
         excluding: Optional[str] = None,
     ) -> Seen:
         """
         Given an image name, and optionally a path, return the number of times
         they occur (alongside one another) in the table.
 
-        If no path is provided, just count the image_name.
+        If no path is provided, just count the process_name.
         """
 
-        count = (
+        query = (
             ProcessQuery()
             .only_first(2)
-            .with_image_name(eq=parent_image_name)
-            .with_node_key(eq=Not(excluding))
-            .with_child(ProcessQuery().with_image_name(eq=child_image_name))
-            .get_count(self.dgraph_client)
+            .with_process_name(eq=parent_process_name)
+            .with_children(ProcessQuery().with_process_name(eq=child_process_name))
         )
 
+        if excluding:
+            query.with_node_key(Not(excluding))
+
+        count = query.get_count(self.dgraph_client)
+
         if count == 0:
             return Seen.Never
         if count == 1:
